:mod:`lck.django.tags.models`
================================

.. automodule:: lck.django.tags.models

Classes
-------

.. autoclass:: TaggableBase
   :show-inheritance:
   :members:
   :member-order: bysource
   :content: both

.. autoclass:: Taggable
   :show-inheritance:
   :members:
   :member-order: bysource
   :content: both

.. autoclass:: TagStem
   :show-inheritance:
   :members:
   :member-order: bysource
   :content: both

.. autoclass:: TagStemManager
   :show-inheritance:
   :members:
   :member-order: bysource
   :content: both

.. autoclass:: Tag
   :show-inheritance:
   :members:
   :member-order: bysource
   :content: both
